@@ -124,6 +124,12 @@ def add_pretty_traceback(**install_kwargs: Any) -> None:
 
 
 class RichArgumentParser(ArgumentParser):
+    theme: SpringsTheme
+    entrypoint: Optional[str]
+    arguments: Optional[str]
+    formatted: Dict[str, Any]
+    console_kwargs: Dict[str, Any]
+
     def __init__(
         self,
         *args,
@@ -352,7 +358,7 @@ class ConfigTreeParser:
                 + Text(text=": ", style=theme.r_leaf)
                 + Text(text=f"({type_name})", style=theme.r_leaf)
                 + Text(text=" = ", style=theme.r_leaf)
-                + Text(text=spec.value, style=theme.r_leaf)
+                + Text(text=str(spec.value), style=theme.r_leaf)
             )
 
             # Add help if available; print it a gray color and italic.
